==> google_applovin_unity_ads-2.0.5.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/AppStateNotifier.java <==
// Copyright 2022 Bitcoding

package com.btcpiyush.ads.google_applovin_unity_ads;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.Lifecycle.Event;
import androidx.lifecycle.LifecycleEventObserver;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.ProcessLifecycleOwner;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.EventChannel.EventSink;
import io.flutter.plugin.common.EventChannel.StreamHandler;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** Listens to changes in app foreground/background and forwards events to Flutter. */
final class AppStateNotifier implements LifecycleEventObserver, MethodCallHandler, StreamHandler {

  private static final String METHOD_CHANNEL_NAME =
      "plugins.flutter.io/google_mobile_ads/app_state_method";
  private static final String EVENT_CHANNEL_NAME =
      "plugins.flutter.io/google_mobile_ads/app_state_event";

  @NonNull private final MethodChannel methodChannel;
  @NonNull private final EventChannel eventChannel;

  @Nullable private EventSink events;

  AppStateNotifier(BinaryMessenger binaryMessenger) {
    methodChannel = new MethodChannel(binaryMessenger, METHOD_CHANNEL_NAME);
    methodChannel.setMethodCallHandler(this);
    eventChannel = new EventChannel(binaryMessenger, EVENT_CHANNEL_NAME);
    eventChannel.setStreamHandler(this);
  }

  /** Starts listening for app lifecycle changes. */
  void start() {
    ProcessLifecycleOwner.get().getLifecycle().addObserver(this);
  }

  /** Stops listening for app lifecycle changes. */
  void stop() {
    ProcessLifecycleOwner.get().getLifecycle().removeObserver(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    switch (call.method) {
      case "start":
        start();
        break;
      case "stop":
        stop();
        break;
      default:
        result.notImplemented();
    }
  }

  @Override
  public void onStateChanged(@NonNull LifecycleOwner source, @NonNull Event event) {
    if (event == Event.ON_START && events != null) {
      events.success("foreground");
    } else if (event == Event.ON_STOP && events != null) {
      events.success("background");
    }
  }

  @Override
  public void onListen(Object arguments, EventSink events) {
    this.events = events;
  }

  @Override
  public void onCancel(Object arguments) {
    this.events = null;
  }
}

==> google_applovin_unity_ads-2.1.1.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/AppStateNotifier.java <==
// Copyright 2022 Bitcoding

package com.btcpiyush.ads.google_applovin_unity_ads;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.lifecycle.Lifecycle.Event;
import androidx.lifecycle.LifecycleEventObserver;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.ProcessLifecycleOwner;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.EventChannel.EventSink;
import io.flutter.plugin.common.EventChannel.StreamHandler;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** Listens to changes in app foreground/background and forwards events to Flutter. */
class AppStateNotifier implements LifecycleEventObserver, MethodCallHandler, StreamHandler {

  private static final String METHOD_CHANNEL_NAME =
      "plugins.flutter.io/google_mobile_ads/app_state_method";
  private static final String EVENT_CHANNEL_NAME =
      "plugins.flutter.io/google_mobile_ads/app_state_event";

  @NonNull private final MethodChannel methodChannel;
  @NonNull private final EventChannel eventChannel;

  @Nullable private EventSink events;

  AppStateNotifier(BinaryMessenger binaryMessenger) {
    methodChannel = new MethodChannel(binaryMessenger, METHOD_CHANNEL_NAME);
    methodChannel.setMethodCallHandler(this);
    eventChannel = new EventChannel(binaryMessenger, EVENT_CHANNEL_NAME);
    eventChannel.setStreamHandler(this);
  }

  /** Starts listening for app lifecycle changes. */
  void start() {
    ProcessLifecycleOwner.get().getLifecycle().addObserver(this);
  }

  /** Stops listening for app lifecycle changes. */
  void stop() {
    ProcessLifecycleOwner.get().getLifecycle().removeObserver(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    switch (call.method) {
      case "start":
        start();
        break;
      case "stop":
        stop();
        break;
      default:
        result.notImplemented();
    }
  }

  @Override
  public void onStateChanged(@NonNull LifecycleOwner source, @NonNull Event event) {
    if (event == Event.ON_START && events != null) {
      events.success("foreground");
    } else if (event == Event.ON_STOP && events != null) {
      events.success("background");
    }
  }

  @Override
  public void onListen(Object arguments, EventSink events) {
    this.events = events;
  }

  @Override
  public void onCancel(Object arguments) {
    this.events = null;
  }
}
